@@ -4,8 +4,9 @@ use strict;
 use warnings;
 use Carp qw/croak/;
 use XSLoader;
+use Sereal::Path::Iterator;
 
-our $VERSION    = '0.010';
+our $VERSION    = '0.011';
 our $XS_VERSION = $VERSION; $VERSION= eval $VERSION;
 
 XSLoader::load(__PACKAGE__, $Sereal::Path::Tie::VERSION);
@@ -20,4 +21,4 @@ __END__
 
 Sereal::Path::Tie - interface to Sereal documents via tied variables
 
-=end
+=cut
